@@ -67,9 +67,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "configuration.h"
-#include "vas.h"
-#include "miniobj.h"
-#include "uthash.h"
+#include "foreign/vas.h"
+#include "foreign/miniobj.h"
+#include "foreign/uthash.h"
 
 extern int yylex (void);
 extern int yyparse(hitch_config *);
@@ -570,12 +570,12 @@ static const yytype_uint16 yyrline[] =
       91,    92,    93,    94,    95,    99,   106,   105,   118,   120,
      121,   125,   126,   127,   128,   129,   130,   131,   132,   133,
      134,   137,   138,   140,   143,   144,   148,   149,   150,   153,
-     155,   161,   169,   175,   180,   185,   201,   200,   217,   219,
-     224,   240,   256,   256,   267,   267,   269,   270,   271,   272,
-     273,   274,   279,   281,   283,   285,   287,   302,   317,   317,
-     326,   326,   328,   329,   330,   331,   333,   335,   340,   347,
-     354,   361,   360,   382,   383,   385,   390,   392,   399,   406,
-     408,   410,   415,   420,   422,   429
+     155,   161,   169,   177,   182,   187,   203,   202,   219,   221,
+     226,   242,   258,   258,   269,   269,   271,   272,   273,   274,
+     275,   276,   281,   283,   285,   287,   289,   304,   319,   319,
+     328,   328,   330,   331,   332,   333,   335,   337,   342,   349,
+     356,   363,   362,   384,   385,   387,   392,   394,   401,   408,
+     410,   412,   417,   422,   424,   431
 };
 #endif
 
@@ -1571,28 +1571,30 @@ yyreduce:
     {
 	if ((yyvsp[0].s))
 		cfg->OCSP_DIR = strdup((yyvsp[0].s));
+	else
+		cfg->OCSP_DIR = NULL;
 }
-#line 1576 "cfg_parser.c" /* yacc.c:1646  */
+#line 1578 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 63:
-#line 176 "cfg_parser.y" /* yacc.c:1646  */
+#line 178 "cfg_parser.y" /* yacc.c:1646  */
     {
 	cfg->OCSP_RESP_TMO = (yyvsp[0].i);
 }
-#line 1584 "cfg_parser.c" /* yacc.c:1646  */
+#line 1586 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 64:
-#line 181 "cfg_parser.y" /* yacc.c:1646  */
+#line 183 "cfg_parser.y" /* yacc.c:1646  */
     {
 	cfg->OCSP_CONN_TMO = (yyvsp[0].i);
 }
-#line 1592 "cfg_parser.c" /* yacc.c:1646  */
+#line 1594 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 65:
-#line 186 "cfg_parser.y" /* yacc.c:1646  */
+#line 188 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) != NULL) {
 		int r;
@@ -1607,21 +1609,21 @@ yyreduce:
 		cfg_cert_add(cert, &cur_fa->certs);
 	}
 }
-#line 1611 "cfg_parser.c" /* yacc.c:1646  */
+#line 1613 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 66:
-#line 201 "cfg_parser.y" /* yacc.c:1646  */
+#line 203 "cfg_parser.y" /* yacc.c:1646  */
     {
 	/* NB: Mid-rule action */
 	AZ(cur_pem);
 	cur_pem = cfg_cert_file_new();
 }
-#line 1621 "cfg_parser.c" /* yacc.c:1646  */
+#line 1623 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 67:
-#line 207 "cfg_parser.y" /* yacc.c:1646  */
+#line 209 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cfg_cert_vfy(cur_pem) != 0)
 		cfg_cert_add(cur_pem, &cur_fa->certs);
@@ -1631,25 +1633,25 @@ yyreduce:
 	}
 	cur_pem = NULL;
 }
-#line 1635 "cfg_parser.c" /* yacc.c:1646  */
+#line 1637 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 68:
-#line 217 "cfg_parser.y" /* yacc.c:1646  */
+#line 219 "cfg_parser.y" /* yacc.c:1646  */
     { cur_fa->match_global_certs = (yyvsp[0].i); }
-#line 1641 "cfg_parser.c" /* yacc.c:1646  */
+#line 1643 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 69:
-#line 220 "cfg_parser.y" /* yacc.c:1646  */
+#line 222 "cfg_parser.y" /* yacc.c:1646  */
     {
 		cur_fa->sni_nomatch_abort = (yyvsp[0].i);
 }
-#line 1649 "cfg_parser.c" /* yacc.c:1646  */
+#line 1651 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 70:
-#line 224 "cfg_parser.y" /* yacc.c:1646  */
+#line 226 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cur_fa->selected_protos != 0) {
 		fprintf(stderr, "%s (%s, line %d):"
@@ -1666,11 +1668,11 @@ yyreduce:
 		fprintf(stderr,
 		    "Warning: tsl = off is deprecated and has no effect.\n");
 }
-#line 1670 "cfg_parser.c" /* yacc.c:1646  */
+#line 1672 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 71:
-#line 240 "cfg_parser.y" /* yacc.c:1646  */
+#line 242 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cur_fa->selected_protos != 0) {
 		fprintf(stderr, "%s (%s, line %d):"
@@ -1687,11 +1689,11 @@ yyreduce:
 		fprintf(stderr,
 		    "Warning: ssl = off is deprecated and has no effect.\n");
 }
-#line 1691 "cfg_parser.c" /* yacc.c:1646  */
+#line 1693 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 72:
-#line 256 "cfg_parser.y" /* yacc.c:1646  */
+#line 258 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cur_fa->selected_protos != 0) {
 		fprintf(stderr, "%s (%s, line %d):"
@@ -1703,73 +1705,73 @@ yyreduce:
 		YYABORT;
 	}
 }
-#line 1707 "cfg_parser.c" /* yacc.c:1646  */
+#line 1709 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 76:
-#line 269 "cfg_parser.y" /* yacc.c:1646  */
+#line 271 "cfg_parser.y" /* yacc.c:1646  */
     { cur_fa->selected_protos |= SSLv3_PROTO; }
-#line 1713 "cfg_parser.c" /* yacc.c:1646  */
+#line 1715 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 77:
-#line 270 "cfg_parser.y" /* yacc.c:1646  */
+#line 272 "cfg_parser.y" /* yacc.c:1646  */
     { cur_fa->selected_protos |= TLSv1_0_PROTO; }
-#line 1719 "cfg_parser.c" /* yacc.c:1646  */
+#line 1721 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 78:
-#line 271 "cfg_parser.y" /* yacc.c:1646  */
+#line 273 "cfg_parser.y" /* yacc.c:1646  */
     { cur_fa->selected_protos |= TLSv1_1_PROTO; }
-#line 1725 "cfg_parser.c" /* yacc.c:1646  */
+#line 1727 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 79:
-#line 272 "cfg_parser.y" /* yacc.c:1646  */
+#line 274 "cfg_parser.y" /* yacc.c:1646  */
     { cur_fa->selected_protos |= TLSv1_2_PROTO; }
-#line 1731 "cfg_parser.c" /* yacc.c:1646  */
+#line 1733 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 80:
-#line 273 "cfg_parser.y" /* yacc.c:1646  */
+#line 275 "cfg_parser.y" /* yacc.c:1646  */
     { if ((yyvsp[0].s)) cur_fa->ciphers = strdup((yyvsp[0].s)); }
-#line 1737 "cfg_parser.c" /* yacc.c:1646  */
+#line 1739 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 81:
-#line 275 "cfg_parser.y" /* yacc.c:1646  */
+#line 277 "cfg_parser.y" /* yacc.c:1646  */
     {
 	cur_fa->prefer_server_ciphers = (yyvsp[0].i);
 }
-#line 1745 "cfg_parser.c" /* yacc.c:1646  */
+#line 1747 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 82:
-#line 279 "cfg_parser.y" /* yacc.c:1646  */
+#line 281 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->QUIET = (yyvsp[0].i); }
-#line 1751 "cfg_parser.c" /* yacc.c:1646  */
+#line 1753 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 83:
-#line 281 "cfg_parser.y" /* yacc.c:1646  */
+#line 283 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->NCORES = (yyvsp[0].i); }
-#line 1757 "cfg_parser.c" /* yacc.c:1646  */
+#line 1759 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 84:
-#line 283 "cfg_parser.y" /* yacc.c:1646  */
+#line 285 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->BACKLOG = (yyvsp[0].i); }
-#line 1763 "cfg_parser.c" /* yacc.c:1646  */
+#line 1765 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 85:
-#line 285 "cfg_parser.y" /* yacc.c:1646  */
+#line 287 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->TCP_KEEPALIVE_TIME = (yyvsp[0].i); }
-#line 1769 "cfg_parser.c" /* yacc.c:1646  */
+#line 1771 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 86:
-#line 287 "cfg_parser.y" /* yacc.c:1646  */
+#line 289 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cfg->SELECTED_TLS_PROTOS != 0) {
 		fprintf(stderr, "%s (%s, line %d):"
@@ -1784,11 +1786,11 @@ yyreduce:
 		fprintf(stderr,
 		    "Warning: tsl = off is deprecated and has no effect.\n");
 }
-#line 1788 "cfg_parser.c" /* yacc.c:1646  */
+#line 1790 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 87:
-#line 302 "cfg_parser.y" /* yacc.c:1646  */
+#line 304 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cfg->SELECTED_TLS_PROTOS != 0) {
 		fprintf(stderr, "%s (%s, line %d):"
@@ -1803,11 +1805,11 @@ yyreduce:
 		fprintf(stderr,
 		    "Warning: ssl = off is deprecated and has no effect.\n");
 }
-#line 1807 "cfg_parser.c" /* yacc.c:1646  */
+#line 1809 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 88:
-#line 317 "cfg_parser.y" /* yacc.c:1646  */
+#line 319 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cfg->SELECTED_TLS_PROTOS != 0) {
 		fprintf(stderr, "%s (%s, line %d):"
@@ -1817,89 +1819,89 @@ yyreduce:
 		YYABORT;
 	}
 }
-#line 1821 "cfg_parser.c" /* yacc.c:1646  */
+#line 1823 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 92:
-#line 328 "cfg_parser.y" /* yacc.c:1646  */
+#line 330 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->SELECTED_TLS_PROTOS |= SSLv3_PROTO; }
-#line 1827 "cfg_parser.c" /* yacc.c:1646  */
+#line 1829 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 93:
-#line 329 "cfg_parser.y" /* yacc.c:1646  */
+#line 331 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->SELECTED_TLS_PROTOS |= TLSv1_0_PROTO; }
-#line 1833 "cfg_parser.c" /* yacc.c:1646  */
+#line 1835 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 94:
-#line 330 "cfg_parser.y" /* yacc.c:1646  */
+#line 332 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->SELECTED_TLS_PROTOS |= TLSv1_1_PROTO; }
-#line 1839 "cfg_parser.c" /* yacc.c:1646  */
+#line 1841 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 95:
-#line 331 "cfg_parser.y" /* yacc.c:1646  */
+#line 333 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->SELECTED_TLS_PROTOS |= TLSv1_2_PROTO; }
-#line 1845 "cfg_parser.c" /* yacc.c:1646  */
+#line 1847 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 96:
-#line 333 "cfg_parser.y" /* yacc.c:1646  */
+#line 335 "cfg_parser.y" /* yacc.c:1646  */
     { if ((yyvsp[0].s)) cfg->ENGINE = strdup((yyvsp[0].s)); }
-#line 1851 "cfg_parser.c" /* yacc.c:1646  */
+#line 1853 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 97:
-#line 336 "cfg_parser.y" /* yacc.c:1646  */
+#line 338 "cfg_parser.y" /* yacc.c:1646  */
     {
 	cfg->PREFER_SERVER_CIPHERS = (yyvsp[0].i);
 }
-#line 1859 "cfg_parser.c" /* yacc.c:1646  */
+#line 1861 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 98:
-#line 341 "cfg_parser.y" /* yacc.c:1646  */
+#line 343 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) && config_param_validate("chroot", (yyvsp[0].s), cfg, /* XXX: */ "",
 	    yyget_lineno()) != 0)
 		YYABORT;
 }
-#line 1869 "cfg_parser.c" /* yacc.c:1646  */
+#line 1871 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 99:
-#line 348 "cfg_parser.y" /* yacc.c:1646  */
+#line 350 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) && config_param_validate("backend", (yyvsp[0].s), cfg, /* XXX: */ "",
 	    yyget_lineno()) != 0)
 		YYABORT;
 }
-#line 1879 "cfg_parser.c" /* yacc.c:1646  */
+#line 1881 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 100:
-#line 355 "cfg_parser.y" /* yacc.c:1646  */
+#line 357 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) && config_param_validate("pem-file", (yyvsp[0].s), cfg, /* XXX: */ "",
 	    yyget_lineno()) != 0)
 		YYABORT;
 }
-#line 1889 "cfg_parser.c" /* yacc.c:1646  */
+#line 1891 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 101:
-#line 361 "cfg_parser.y" /* yacc.c:1646  */
+#line 363 "cfg_parser.y" /* yacc.c:1646  */
     {
 	/* NB: Mid-rule action */
 	AZ(cur_pem);
 	cur_pem = cfg_cert_file_new();
 }
-#line 1899 "cfg_parser.c" /* yacc.c:1646  */
+#line 1901 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 102:
-#line 367 "cfg_parser.y" /* yacc.c:1646  */
+#line 369 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if (cfg_cert_vfy(cur_pem) != 0) {
 		if (cfg->CERT_DEFAULT != NULL) {
@@ -1913,112 +1915,112 @@ yyreduce:
 	}
 	cur_pem = NULL;
 }
-#line 1917 "cfg_parser.c" /* yacc.c:1646  */
+#line 1919 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 103:
-#line 382 "cfg_parser.y" /* yacc.c:1646  */
+#line 384 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->SYSLOG = (yyvsp[0].i); }
-#line 1923 "cfg_parser.c" /* yacc.c:1646  */
+#line 1925 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 104:
-#line 383 "cfg_parser.y" /* yacc.c:1646  */
+#line 385 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->DAEMONIZE = (yyvsp[0].i); }
-#line 1929 "cfg_parser.c" /* yacc.c:1646  */
+#line 1931 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 105:
-#line 386 "cfg_parser.y" /* yacc.c:1646  */
+#line 388 "cfg_parser.y" /* yacc.c:1646  */
     {
 	cfg->SNI_NOMATCH_ABORT = (yyvsp[0].i);
 }
-#line 1937 "cfg_parser.c" /* yacc.c:1646  */
+#line 1939 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 106:
-#line 390 "cfg_parser.y" /* yacc.c:1646  */
+#line 392 "cfg_parser.y" /* yacc.c:1646  */
     { if ((yyvsp[0].s)) cfg->CIPHER_SUITE = strdup((yyvsp[0].s)); }
-#line 1943 "cfg_parser.c" /* yacc.c:1646  */
+#line 1945 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 107:
-#line 393 "cfg_parser.y" /* yacc.c:1646  */
+#line 395 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) && config_param_validate("user", (yyvsp[0].s), cfg, /* XXX: */ "",
 	    yyget_lineno()) != 0)
 		YYABORT;
 }
-#line 1953 "cfg_parser.c" /* yacc.c:1646  */
+#line 1955 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 108:
-#line 400 "cfg_parser.y" /* yacc.c:1646  */
+#line 402 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) && config_param_validate("group", (yyvsp[0].s), cfg, /* XXX: */ "",
 	    yyget_lineno()) != 0)
 		YYABORT;
 }
-#line 1963 "cfg_parser.c" /* yacc.c:1646  */
+#line 1965 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 109:
-#line 406 "cfg_parser.y" /* yacc.c:1646  */
+#line 408 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->WRITE_IP_OCTET = (yyvsp[0].i); }
-#line 1969 "cfg_parser.c" /* yacc.c:1646  */
+#line 1971 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 110:
-#line 408 "cfg_parser.y" /* yacc.c:1646  */
+#line 410 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->WRITE_PROXY_LINE_V2 = (yyvsp[0].i); }
-#line 1975 "cfg_parser.c" /* yacc.c:1646  */
+#line 1977 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 111:
-#line 411 "cfg_parser.y" /* yacc.c:1646  */
+#line 413 "cfg_parser.y" /* yacc.c:1646  */
     {
 	cfg->WRITE_PROXY_LINE_V1 = (yyvsp[0].i);
 }
-#line 1983 "cfg_parser.c" /* yacc.c:1646  */
+#line 1985 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 112:
-#line 416 "cfg_parser.y" /* yacc.c:1646  */
+#line 418 "cfg_parser.y" /* yacc.c:1646  */
     {
 	cfg->WRITE_PROXY_LINE_V2 = (yyvsp[0].i);
 }
-#line 1991 "cfg_parser.c" /* yacc.c:1646  */
+#line 1993 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 113:
-#line 420 "cfg_parser.y" /* yacc.c:1646  */
+#line 422 "cfg_parser.y" /* yacc.c:1646  */
     { cfg->PROXY_PROXY_LINE = (yyvsp[0].i); }
-#line 1997 "cfg_parser.c" /* yacc.c:1646  */
+#line 1999 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 114:
-#line 423 "cfg_parser.y" /* yacc.c:1646  */
+#line 425 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) && config_param_validate("alpn-protos", (yyvsp[0].s), cfg, /* XXX: */ "",
 	    yyget_lineno()) != 0)
 		YYABORT;
 }
-#line 2007 "cfg_parser.c" /* yacc.c:1646  */
+#line 2009 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
   case 115:
-#line 430 "cfg_parser.y" /* yacc.c:1646  */
+#line 432 "cfg_parser.y" /* yacc.c:1646  */
     {
 	if ((yyvsp[0].s) &&
 	    config_param_validate("syslog-facility", (yyvsp[0].s), cfg, /* XXX: */ "",
 	    yyget_lineno()) != 0)
 		YYABORT;
 }
-#line 2018 "cfg_parser.c" /* yacc.c:1646  */
+#line 2020 "cfg_parser.c" /* yacc.c:1646  */
     break;
 
 
-#line 2022 "cfg_parser.c" /* yacc.c:1646  */
+#line 2024 "cfg_parser.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2246,7 +2248,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 437 "cfg_parser.y" /* yacc.c:1906  */
+#line 439 "cfg_parser.y" /* yacc.c:1906  */
 
 
 void
