@@ -20,16 +20,18 @@
 #include <libgen.h>
 
 #include "config.h"
-#include "miniobj.h"
 #include "configuration.h"
-#include "vas.h"
-#include "vsb.h"
+#include "foreign/miniobj.h"
+#include "foreign/vas.h"
+#include "foreign/vsb.h"
+
 #include "cfg_parser.h"
 
 #define ADDR_LEN 150
 #define PORT_LEN 6
 #define CFG_BOOL_ON "on"
 
+
 // BEGIN: configuration parameters
 #define CFG_CIPHERS "ciphers"
 #define CFG_SSL_ENGINE "ssl-engine"
@@ -179,7 +181,7 @@ config_new(void)
 	r->BACK_IP            = strdup("127.0.0.1");
 	r->BACK_PORT          = strdup("8000");
 	r->NCORES             = 1;
-	r->CIPHER_SUITE       = NULL;
+	r->CIPHER_SUITE       = strdup("EECDH+AESGCM:EDH+AESGCM:AES256+EECDH:AES256+EDH");
 	r->ENGINE             = NULL;
 	r->BACKLOG            = 100;
 	r->SNI_NOMATCH_ABORT  = 0;
@@ -191,6 +193,7 @@ config_new(void)
 	fa->pspec = strdup("default");
 	HASH_ADD_KEYPTR(hh, r->LISTEN_ARGS, fa->pspec, strlen(fa->pspec), fa);
 	r->LISTEN_DEFAULT = fa;
+	r->OCSP_DIR           = strdup("/var/lib/hitch/");
 	r->OCSP_VFY = 0;
 	r->OCSP_RESP_TMO = 10.0;
 	r->OCSP_CONN_TMO = 4.0;
@@ -1351,9 +1354,6 @@ config_parse_cli(int argc, char **argv, hitch_config *cfg, int *retval)
 		AN(cfg->ALPN_PROTOS_LV);
 		int multi_proto =
 		    cfg->ALPN_PROTOS_LV[0] != cfg->ALPN_PROTOS_LV_LEN - 1;
-		if (0 == strncmp((char *)cfg->ALPN_PROTOS_LV, "\x8http/1.1", 9)
-		    && !multi_proto)
-			fprintf(stderr, "standard protocol in use\n");
 		if (multi_proto && !cfg->WRITE_PROXY_LINE_V2) {
 			config_error_set("alpn-protos is specified with"
 			    " more than one protocol while proxy-v2 is "
@@ -1380,18 +1380,17 @@ config_parse_cli(int argc, char **argv, hitch_config *cfg, int *retval)
 		/* No support for ALPN / NPN support in OpenSSL */
 		if (multi_proto ||
 		    0 != strncmp(cfg->ALPN_PROTOS_LV, "\x8http/1.1", 9)) {
-			config_error_set("This is compiled against SSL version"
-			    " %lx, which does not have no NPN or ALPN support,"
+			config_error_set("This is compiled against OpenSSL version"
+			    " %lx, which does not have NPN or ALPN support,"
 			    " yet alpn-protos has been set to %s.",
 			    OPENSSL_VERSION_NUMBER, cfg->ALPN_PROTOS);
 			*retval = 1;
 			return (1);
 		}
 		else
-			fprintf(stderr, "This is compiled against SSL version"
-			    " %lx, which does not have no NPN or ALPN support,"
-			    " but since alpn-protos has been set to http/1.1,"
-			    " we carry on without ALPN/NPN.\n",
+			fprintf(stderr, "This is compiled against OpenSSL version"
+			    " %lx, which does not have NPN or ALPN support."
+			    " alpn-protos setting \"http/1.1\" will be ignored.\n",
 			    OPENSSL_VERSION_NUMBER);
 #endif
 	}
@@ -1421,17 +1420,21 @@ config_parse_cli(int argc, char **argv, hitch_config *cfg, int *retval)
 
 	if (cfg->OCSP_DIR != NULL) {
 		struct stat sb;
+
 		if (stat(cfg->OCSP_DIR, &sb) != 0) {
-			config_error_set("ocsp-dir: Unable to stat directory"
-			    " '%s': %s'.", cfg->OCSP_DIR, strerror(errno));
-			*retval = 1;
-			return (1);
+			fprintf(stderr,
+			    "{ocsp} Warning: Unable to stat directory '%s': %s'."
+			    " OCSP stapling will be disabled.\n",
+			    cfg->OCSP_DIR, strerror(errno));
+			free(cfg->OCSP_DIR);
+			cfg->OCSP_DIR = NULL;
 		} else {
 			if (!S_ISDIR(sb.st_mode)) {
-				config_error_set("Bad ocsp-dir "
-				    "'%s': Not a directory.", cfg->OCSP_DIR);
-				*retval = 1;
-				return (1);
+				fprintf(stderr, "{ocsp} Bad ocsp-dir "
+				    "'%s': Not a directory."
+				    " OCSP stapling will be disabled.\n", cfg->OCSP_DIR);
+				free(cfg->OCSP_DIR);
+				cfg->OCSP_DIR = NULL;
 			}
 		}
 	}
