@@ -5,11 +5,14 @@
  *
  */
 
+#ifndef CONFIGURATION_H_INCLUDED
+#define CONFIGURATION_H_INCLUDED
+
 #include <sys/types.h>
 #include <openssl/opensslv.h>
 
-#include "vqueue.h"
-#include "uthash.h"
+#include "foreign/vqueue.h"
+#include "foreign/uthash.h"
 
 /* Is NPN available? See openssl/opensslv.h for explanation. */
 #if OPENSSL_VERSION_NUMBER >= 0x1000100fL
@@ -152,3 +155,5 @@ int config_file_parse (char *file, hitch_config *cfg);
 int config_parse_cli(int argc, char **argv, hitch_config *cfg, int *rv);
 
 int create_alpn_callback_data(hitch_config *cfg, char **error);
+
+#endif  /* CONFIGURATION_H_INCLUDED */
